==> haskell-yesod-persistent-1.4.1.1-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.1.1
id: yesod-persistent-1.4.1.1-5DayC5aOG9xK1uehtIjY71
key: yesod-persistent-1.4.1.1-5DayC5aOG9xK1uehtIjY71
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
abi: ece838abecc75e1c46187999465e0e74
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-persistent-1.4.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-persistent-1.4.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-persistent-1.4.1.1
hs-libraries: HSyesod-persistent-1.4.1.1-5DayC5aOG9xK1uehtIjY71
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    persistent-2.6-KYIHYYQLKxD6YqkzGIZ4KC
    persistent-template-2.5.1.6-8jcPCrWUFZXGYMvMIPx6YE
    resource-pool-0.2.3.2-3moP3n1CqLz53yrpIJMjdi
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa transformers-0.5.2.0
    yesod-core-1.4.31-EYGWGizBsQ4AsJ9mdJSaog
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.4.1.1-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.1.1
id: yesod-persistent-1.4.1.1-Has4qRz3l3b7IP2oMgU3FG
key: yesod-persistent-1.4.1.1-Has4qRz3l3b7IP2oMgU3FG
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
abi: 6c2c043897373204ab9e071ebc1fb4b5
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-persistent-1.4.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-persistent-1.4.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-persistent-1.4.1.1
hs-libraries: HSyesod-persistent-1.4.1.1-Has4qRz3l3b7IP2oMgU3FG
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    persistent-2.6-DK0rT54hFM1EJQlVqTzrL8
    persistent-template-2.5.1.6-2GhwgFn9wTMFDwJllRRUY4
    resource-pool-0.2.3.2-3moP3n1CqLz53yrpIJMjdi
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa transformers-0.5.2.0
    yesod-core-1.4.31-In0kfFmAB0pFD51cgqrjPT
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
